==> jc-1.4.0.tar.gz: soot/jimple/toolkits/typing/integer/TypeException.h <==
// public class soot.jimple.toolkits.typing.integer.TypeException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7bae04dcd74c4c88 soot_jimple_toolkits_typing_integer_TypeException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_jimple_toolkits_typing_integer_TypeException_H_
#define _JC_soot_jimple_toolkits_typing_integer_TypeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs	_jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs	_jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$refs	_jc_soot_jimple_toolkits_typing_integer_TypeException$refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs	_jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$object	_jc_soot_jimple_toolkits_typing_integer_TypeException$object;

typedef const struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods	_jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtable	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtype	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_integer_TypeException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_TypeException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods	soot_jimple_toolkits_typing_integer_TypeException;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$refs {
    _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs	soot_jimple_toolkits_typing_integer_TypeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs	soot_jimple_toolkits_typing_integer_TypeException;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$object {
	_jc_soot_jimple_toolkits_typing_integer_TypeException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_integer_TypeException$vtype _jc_soot_jimple_toolkits_typing_integer_TypeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_integer_TypeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_integer_TypeException$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_integer_TypeException_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/typing/integer/TypeException.h <==
// public class soot.jimple.toolkits.typing.integer.TypeException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7bae04dcd74c4c88 soot_jimple_toolkits_typing_integer_TypeException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_soot_jimple_toolkits_typing_integer_TypeException_H_
#define _JC_soot_jimple_toolkits_typing_integer_TypeException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs	_jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs	_jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$refs	_jc_soot_jimple_toolkits_typing_integer_TypeException$refs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs	_jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs;
typedef struct _jc_soot_jimple_toolkits_typing_integer_TypeException$object	_jc_soot_jimple_toolkits_typing_integer_TypeException$object;

typedef const struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods	_jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtable	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtable;
typedef const struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtype	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_typing_integer_TypeException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_typing_integer_TypeException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods {
};

// Vtable
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$vmethods	soot_jimple_toolkits_typing_integer_TypeException;
};

// Vtype
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$refs {
    _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_refs	soot_jimple_toolkits_typing_integer_TypeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_soot_jimple_toolkits_typing_integer_TypeException$sub_nonrefs	soot_jimple_toolkits_typing_integer_TypeException;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_typing_integer_TypeException$object {
	_jc_soot_jimple_toolkits_typing_integer_TypeException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$vtype	*vtype;
	_jc_soot_jimple_toolkits_typing_integer_TypeException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_typing_integer_TypeException$vtype _jc_soot_jimple_toolkits_typing_integer_TypeException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_typing_integer_TypeException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_typing_integer_TypeException$class_object;

#endif	/* _JC_soot_jimple_toolkits_typing_integer_TypeException_H_ */
